==> _private_core_network-0.0.79.tar.gz: lib/network_resources/model/service_around_me_model.dart <==
class ServicesAroundMeModel {
  int? proId;
  String? proDisplayName;
  String? proThumbnail;
  String? proUniqueId;
  int? rating;
  String? firebaseId;
  int? allowChat;
  int? serviceId;
  String? serviceLabel;
  String? serviceInfos;
  String? thumbnailService;
  int? serviceTypeId;
  String? serviceName;
  double? lat;
  double? lng;
  int? actualDistance;
  List<Subcat>? subcat;

  int marketClickCount = 0;

  ServicesAroundMeModel(
      {this.proId,
      this.proDisplayName,
      this.proThumbnail,
      this.proUniqueId,
      this.rating,
      this.firebaseId,
      this.allowChat,
      this.serviceId,
      this.serviceLabel,
      this.serviceInfos,
      this.thumbnailService,
      this.serviceTypeId,
      this.serviceName,
      this.lat,
      this.lng,
      this.actualDistance,
      this.subcat});

  ServicesAroundMeModel.fromJson(Map<String, dynamic> json) {
    proId = json['proId'];
    proDisplayName = json['proDisplayName'];
    proThumbnail = json['proThumbnail'];
    proUniqueId = json['proUniqueId'];
    rating = json['rating'];
    firebaseId = json['firebaseId'];
    allowChat = json['allowChat'];
    serviceId = json['serviceId'];
    serviceLabel = json['serviceLabel'];
    serviceInfos = json['serviceInfos'];
    thumbnailService = json['thumbnailService'];
    serviceTypeId = json['serviceTypeId'];
    serviceName = json['serviceName'];
    lat = json['lat'];
    lng = json['lng'];
    actualDistance = json['actualDistance'];
    if (json['subcat'] != null) {
      subcat = [];
      json['subcat'].forEach((v) {
        subcat!.add(new Subcat.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['proId'] = this.proId;
    data['proDisplayName'] = this.proDisplayName;
    data['proThumbnail'] = this.proThumbnail;
    data['proUniqueId'] = this.proUniqueId;
    data['rating'] = this.rating;
    data['firebaseId'] = this.firebaseId;
    data['allowChat'] = this.allowChat;
    data['serviceId'] = this.serviceId;
    data['serviceLabel'] = this.serviceLabel;
    data['serviceInfos'] = this.serviceInfos;
    data['thumbnailService'] = this.thumbnailService;
    data['serviceTypeId'] = this.serviceTypeId;
    data['serviceName'] = this.serviceName;
    data['lat'] = this.lat;
    data['lng'] = this.lng;
    data['actualDistance'] = this.actualDistance;
    if (this.subcat != null) {
      data['subcat'] = this.subcat!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Subcat {
  String? subcatName;
  int? idSubcat;
  int? id;
  String? colorCode;
  String? pictureUrl;

  Subcat(
      {this.subcatName,
      this.idSubcat,
      this.id,
      this.colorCode,
      this.pictureUrl});

  Subcat.fromJson(Map<String, dynamic> json) {
    subcatName = json['subcatName'];
    idSubcat = json['idSubcat'];
    id = json['id'];
    colorCode = json['colorCode'];
    pictureUrl = json['pictureUrl'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['subcatName'] = this.subcatName;
    data['idSubcat'] = this.idSubcat;
    data['id'] = this.id;
    data['colorCode'] = this.colorCode;
    data['pictureUrl'] = this.pictureUrl;
    return data;
  }
}

==> _private_core_network-1.2.94.tar.gz: lib/network_resources/model/service_around_me_model.dart <==
class ServicesAroundMeModel {
  int? proId;
  String? proDisplayName;
  String? proThumbnail;
  String? proUniqueId;
  int? rating;
  String? firebaseId;
  int? allowChat;
  int? serviceId;
  String? serviceLabel;
  String? serviceInfos;
  String? thumbnailService;
  int? serviceTypeId;
  String? serviceName;
  double? lat;
  double? lng;
  int? actualDistance;
  List<Subcat>? subcat;

  int marketClickCount = 0;

  ServicesAroundMeModel(
      {this.proId,
      this.proDisplayName,
      this.proThumbnail,
      this.proUniqueId,
      this.rating,
      this.firebaseId,
      this.allowChat,
      this.serviceId,
      this.serviceLabel,
      this.serviceInfos,
      this.thumbnailService,
      this.serviceTypeId,
      this.serviceName,
      this.lat,
      this.lng,
      this.actualDistance,
      this.subcat});

  ServicesAroundMeModel.fromJson(Map<String, dynamic> json) {
    proId = json['proId'];
    proDisplayName = json['proDisplayName'];
    proThumbnail = json['proThumbnail'];
    proUniqueId = json['proUniqueId'];
    rating = json['rating'];
    firebaseId = json['firebaseId'];
    allowChat = json['allowChat'];
    serviceId = json['serviceId'];
    serviceLabel = json['serviceLabel'];
    serviceInfos = json['serviceInfos'];
    thumbnailService = json['thumbnailService'];
    serviceTypeId = json['serviceTypeId'];
    serviceName = json['serviceName'];
    lat = json['lat'];
    lng = json['lng'];
    actualDistance = json['actualDistance'];
    if (json['subcat'] != null) {
      subcat = [];
      json['subcat'].forEach((v) {
        subcat!.add(Subcat.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['proId'] = proId;
    data['proDisplayName'] = proDisplayName;
    data['proThumbnail'] = proThumbnail;
    data['proUniqueId'] = proUniqueId;
    data['rating'] = rating;
    data['firebaseId'] = firebaseId;
    data['allowChat'] = allowChat;
    data['serviceId'] = serviceId;
    data['serviceLabel'] = serviceLabel;
    data['serviceInfos'] = serviceInfos;
    data['thumbnailService'] = thumbnailService;
    data['serviceTypeId'] = serviceTypeId;
    data['serviceName'] = serviceName;
    data['lat'] = lat;
    data['lng'] = lng;
    data['actualDistance'] = actualDistance;
    if (subcat != null) {
      data['subcat'] = subcat!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Subcat {
  String? subcatName;
  int? idSubcat;
  int? id;
  String? colorCode;
  String? pictureUrl;

  Subcat(
      {this.subcatName,
      this.idSubcat,
      this.id,
      this.colorCode,
      this.pictureUrl});

  Subcat.fromJson(Map<String, dynamic> json) {
    subcatName = json['subcatName'];
    idSubcat = json['idSubcat'];
    id = json['id'];
    colorCode = json['colorCode'];
    pictureUrl = json['pictureUrl'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['subcatName'] = subcatName;
    data['idSubcat'] = idSubcat;
    data['id'] = id;
    data['colorCode'] = colorCode;
    data['pictureUrl'] = pictureUrl;
    return data;
  }
}
